"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CONFIG_DEST_QUES = exports.QUESTIONAIRRE = exports.MOBILE_BROWSER_QUES = exports.isRemoteMobileTestingSetup = exports.isLocalMobileTestingSetup = exports.isAppTestingSetup = exports.isWebTestingSetup = exports.MOBILE_PLATFORM_CHOICES = exports.MOBILE_BROWSER_CHOICES = exports.BROWSER_CHOICES = exports.AVAILABLE_CONFIG_FLAGS = exports.CONFIG_INTRO = exports.NIGHTWATCH_TITLE = void 0;
const node_fs_1 = __importDefault(require("node:fs"));
const path_1 = __importDefault(require("path"));
exports.NIGHTWATCH_TITLE = `
 _   _  _         _      _                     _          _
| \\ | |(_)       | |    | |                   | |        | |
|  \\| | _   __ _ | |__  | |_ __      __  __ _ | |_   ___ | |__
| . \` || | / _\` || '_ \\ | __|\\ \\ /\\ / / / _\` || __| / __|| '_ \\
| |\\  || || (_| || | | || |_  \\ V  V / | (_| || |_ | (__ | | | |
\\_| \\_/|_| \\__, ||_| |_| \\__|  \\_/\\_/   \\__,_| \\__| \\___||_| |_|
            __/ |
           |___/
`;
exports.CONFIG_INTRO = `===============================
Nightwatch Configuration Wizard
===============================

Setting up Nightwatch in %s...
`;
exports.AVAILABLE_CONFIG_FLAGS = ['yes', 'generate-config', 'browser', 'y', 'b', 'mobile', 'app', 'native'];
const TESTING_TYPE_CHOICES = [
    { name: 'End-to-End testing', value: 'e2e' },
    { name: 'Component testing', value: 'component' },
    { name: 'Mobile app testing', value: 'app' }
];
exports.BROWSER_CHOICES = [
    { name: 'Chrome', value: 'chrome' },
    { name: 'Safari', value: 'safari' },
    { name: 'Firefox', value: 'firefox' },
    { name: 'Edge', value: 'edge' }
];
exports.MOBILE_BROWSER_CHOICES = [
    { name: 'Chrome (Android)', value: 'chrome' },
    { name: 'Firefox (Android)', value: 'firefox' },
    { name: 'Safari (iOS)', value: 'safari' }
];
exports.MOBILE_PLATFORM_CHOICES = [
    { name: 'Android', value: 'android' },
    { name: 'iOS', value: 'ios' },
    { name: 'Both', value: 'both' }
];
const isWebTestingSetup = (answers) => {
    var _a;
    return (_a = answers.testingType) === null || _a === void 0 ? void 0 : _a.some((type) => ['e2e', 'component'].includes(type));
};
exports.isWebTestingSetup = isWebTestingSetup;
const isAppTestingSetup = (answers) => {
    var _a;
    return (_a = answers.testingType) === null || _a === void 0 ? void 0 : _a.includes('app');
};
exports.isAppTestingSetup = isAppTestingSetup;
const isLocalMobileTestingSetup = (answers) => {
    if (answers.backend === 'remote') {
        return false;
    }
    return (answers.mobile || (0, exports.isAppTestingSetup)(answers));
};
exports.isLocalMobileTestingSetup = isLocalMobileTestingSetup;
const isRemoteMobileTestingSetup = (answers) => {
    if (answers.backend === 'local') {
        return false;
    }
    return (answers.mobile || (0, exports.isAppTestingSetup)(answers));
};
exports.isRemoteMobileTestingSetup = isRemoteMobileTestingSetup;
exports.MOBILE_BROWSER_QUES = {
    type: 'checkbox',
    name: 'mobileBrowsers',
    message: 'Select target mobile-browsers',
    choices: () => {
        let devices = exports.MOBILE_BROWSER_CHOICES;
        if (process.platform !== 'darwin') {
            devices = devices.filter((device) => device.value !== 'safari');
        }
        return devices;
    },
    default: ['chrome'],
    validate: (value) => {
        return !!value.length || 'Please select at least 1 browser.';
    },
    when: (answers) => {
        var _a;
        if (!answers.mobile || answers.backend === 'remote') {
            return false;
        }
        const mobileBrowserValues = exports.MOBILE_BROWSER_CHOICES
            .map((browserObj) => browserObj.value);
        const browsersHasMobileBrowsers = (_a = answers.browsers) === null || _a === void 0 ? void 0 : _a.some(((browser) => mobileBrowserValues.includes(browser)));
        return !browsersHasMobileBrowsers;
    }
};
exports.QUESTIONAIRRE = [
    // answers.rootDir is available to all the questions (passed in Inquirer.prompt()).
    // TEST TYPE
    {
        type: 'checkbox',
        name: 'testingType',
        message: 'Select testing type to setup for your project',
        choices: (answers) => {
            let testingTypes = TESTING_TYPE_CHOICES;
            if (answers.mobile) {
                // if --mobile flag is used
                testingTypes = testingTypes.filter((type) => ['e2e', 'component'].includes(type.value));
            }
            return testingTypes;
        },
        default: ['e2e'],
        validate: (value) => {
            return !!value.length || 'Please select at least 1 testing type.';
        },
        when: (answers) => {
            if (answers.native) {
                answers.testingType = ['app'];
                return false;
            }
            return true;
        }
    },
    // JS OR TS
    {
        type: 'list',
        name: 'languageRunnerSetup',
        message: 'Select language + test runner variant',
        choices: (answers) => {
            var _a;
            let languageRunners = [
                { name: 'JavaScript / default', value: 'js-nightwatch' },
                { name: 'TypeScript / default', value: 'ts-nightwatch' },
                { name: 'JavaScript / Mocha', value: 'js-mocha' },
                { name: 'JavaScript / CucumberJS', value: 'js-cucumber' }
                // {name: 'TypeScript - Mocha Test Runner', value: 'ts-mocha'}
                // {name: 'TypeScript - CucumberJS Test Runner', value: 'ts-cucumber'}
            ];
            if ((_a = answers.testingType) === null || _a === void 0 ? void 0 : _a.includes('component')) {
                // component tests only work with default test runner.
                languageRunners = languageRunners.filter((languageRunner) => languageRunner.value.includes('nightwatch'));
            }
            if ((0, exports.isAppTestingSetup)(answers)) {
                // don't allow cucumber for now
                languageRunners = languageRunners.filter((languageRunner) => !languageRunner.value.includes('cucumber'));
            }
            return languageRunners;
        },
        filter: (value, answers) => {
            const [language, runner] = value.split('-');
            answers.language = language;
            answers.runner = runner;
            return value;
        }
    },
    // UI Framework
    {
        type: 'list',
        name: 'uiFramework',
        message: 'Select UI framework',
        choices: [
            { name: 'React', value: 'react' },
            { name: 'Vue.js', value: 'vue' },
            { name: 'Storybook', value: 'storybook' }
        ],
        when: (answers) => { var _a; return (_a = answers.testingType) === null || _a === void 0 ? void 0 : _a.includes('component'); }
    },
    // BROWSERS
    {
        type: 'checkbox',
        name: 'browsers',
        message: 'Select target browsers',
        choices: () => {
            let browsers = exports.BROWSER_CHOICES;
            if (process.platform !== 'darwin') {
                browsers = browsers.filter((browser) => browser.value !== 'safari');
            }
            return browsers;
        },
        default: ['chrome'],
        validate: (value) => {
            return !!value.length || 'Please select at least 1 browser.';
        },
        when: (answers) => {
            if (answers.mobile) {
                // --mobile flag is used.
                return false;
            }
            return (0, exports.isWebTestingSetup)(answers);
        }
    },
    exports.MOBILE_BROWSER_QUES,
    // PLATFORM
    {
        type: 'list',
        name: 'mobilePlatform',
        message: 'Select target mobile platform(s)',
        choices: () => {
            let platforms = exports.MOBILE_PLATFORM_CHOICES;
            if (process.platform !== 'darwin') {
                platforms = platforms.filter((platform) => platform.value === 'android');
            }
            return platforms;
        },
        when: (answers) => (0, exports.isAppTestingSetup)(answers)
    },
    // TEST LOCATION
    {
        type: 'input',
        name: 'testsLocation',
        message: 'Enter source folder where test files are stored',
        default: (answers) => {
            if (answers.uiFramework === 'storybook') {
                return 'stories/*.stories.jsx';
            }
            return 'test';
        }
    },
    {
        type: 'input',
        name: 'featurePath',
        message: 'Enter location of CucumberJS feature files',
        default: (answers) => path_1.default.join(answers.testsLocation, 'features'),
        when: (answers) => answers.runner === 'cucumber'
    },
    // BASE URL
    {
        type: 'input',
        name: 'baseUrl',
        message: 'Enter the base_url of the project',
        default: (answers) => {
            if (answers.uiFramework) {
                if (answers.uiFramework === 'storybook') {
                    return 'http://localhost:6006';
                }
                return 'http://localhost:5173';
            }
            return 'http://localhost';
        },
        when: (answers) => (0, exports.isWebTestingSetup)(answers)
    },
    // TESTING BACKEND
    {
        type: 'list',
        name: 'backend',
        message: 'Select where to run Nightwatch tests',
        choices: (answers) => {
            // temporary change till app-testing is supported on BrowserStack
            const choices = [
                { name: 'On localhost', value: 'local' },
                { name: 'On a remote/cloud service', value: 'remote' },
                { name: 'Both', value: 'both' }
            ];
            if (answers.testingType && answers.testingType.length === 1 && answers.testingType[0] === 'app') {
                return [choices[0]];
            }
            return choices;
        },
        default: 'local'
    },
    {
        type: 'list',
        name: 'cloudProvider',
        message: '(Remote) Select cloud provider:',
        choices: [
            { name: 'BrowserStack', value: 'browserstack' },
            { name: 'Sauce Labs', value: 'saucelabs' },
            { name: 'Other providers or remote selenium-server', value: 'other' }
        ],
        when: (answers) => ['remote', 'both'].includes(answers.backend)
    },
    // ANONYMOUS METRIC COLLECTION
    {
        type: 'confirm',
        name: 'allowAnonymousMetrics',
        message: 'Allow Nightwatch to collect completely anonymous usage metrics?',
        default: false
    },
    // TEST ON MOBILE
    {
        type: 'list',
        name: 'mobile',
        message: 'Setup testing on Mobile devices as well?',
        choices: () => [
            { name: 'Yes', value: true },
            { name: 'No, skip for now', value: false }
        ],
        default: false,
        when: (answers) => {
            if ((0, exports.isWebTestingSetup)(answers) && (0, exports.isAppTestingSetup)(answers)) {
                // setup mobile-web testing as well
                answers.mobile = true;
                return false;
            }
            return (0, exports.isWebTestingSetup)(answers);
        }
    },
    exports.MOBILE_BROWSER_QUES
];
exports.CONFIG_DEST_QUES = [
    {
        type: 'list',
        name: 'overwrite',
        message: 'Overwrite the existing config file?',
        default: false,
        choices: [
            { name: 'Yes', value: true },
            { name: 'No, create a new one', value: false }
        ]
    },
    {
        type: 'input',
        name: 'newFileName',
        message: 'Enter new config file name:',
        validate: (value, answers) => {
            if (!value.length) {
                return 'File name cannot be empty.';
            }
            else if (answers && node_fs_1.default.existsSync(path_1.default.join(answers.rootDir, `${value}${answers.configExt}`))) {
                return `File with name "${value}${answers.configExt}" already exists.`;
            }
            return true;
        },
        transformer: (value, answers) => value + answers.configExt,
        when: (answers) => !answers.overwrite
    }
];
