"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadWithProgressBar = exports.rmDirSync = exports.copy = exports.isNodeProject = exports.symbols = exports.stripControlChars = void 0;
const node_fs_1 = __importDefault(require("node:fs"));
const path_1 = __importDefault(require("path"));
const cli_progress_1 = __importDefault(require("cli-progress"));
const ansi_colors_1 = __importDefault(require("ansi-colors"));
const node_downloader_helper_1 = require("node-downloader-helper");
const logger_1 = __importDefault(require("./logger"));
/**
 * Strips out all control characters from a string
 * However, excludes newline and carriage return
 *
 * @param {string} input String to remove invisible chars from
 * @returns {string} Initial input string but without invisible chars
 */
const stripControlChars = (input) => {
    return (input &&
        input.replace(
        // eslint-disable-next-line no-control-regex
        /[\x00-\x09\x0B-\x0C\x0E-\x1F\x7F-\x9F]/g, ''));
};
exports.stripControlChars = stripControlChars;
const symbols = () => {
    let ok = String.fromCharCode(10004);
    let fail = String.fromCharCode(10006);
    if (process.platform === 'win32') {
        ok = '\u221A';
        fail = '\u00D7';
    }
    return {
        ok: ok,
        fail: fail
    };
};
exports.symbols = symbols;
const isNodeProject = (rootDir) => node_fs_1.default.existsSync(path_1.default.join(rootDir, 'package.json'));
exports.isNodeProject = isNodeProject;
const copy = (src, dest, excludeDir = [], overwrite = false) => {
    const stat = node_fs_1.default.statSync(src);
    if (stat.isDirectory()) {
        return copyDir(src, dest, excludeDir);
    }
    if (node_fs_1.default.existsSync(dest) && !overwrite) {
        return;
    }
    node_fs_1.default.copyFileSync(src, dest);
};
exports.copy = copy;
const copyDir = (srcDir, destDir, excludeDir) => {
    if (excludeDir.some((dir) => srcDir.endsWith(dir))) {
        return;
    }
    node_fs_1.default.mkdirSync(destDir, { recursive: true });
    for (const file of node_fs_1.default.readdirSync(srcDir)) {
        const srcFile = path_1.default.resolve(srcDir, file);
        const destFile = path_1.default.resolve(destDir, file);
        (0, exports.copy)(srcFile, destFile, excludeDir);
    }
};
const rmDirSync = (dirPath) => {
    if (node_fs_1.default.existsSync(dirPath)) {
        node_fs_1.default.readdirSync(dirPath).forEach((file) => {
            const curPath = path_1.default.join(dirPath, file);
            if (node_fs_1.default.lstatSync(curPath).isDirectory()) {
                // recurse
                (0, exports.rmDirSync)(curPath);
            }
            else {
                // delete file
                node_fs_1.default.unlinkSync(curPath);
            }
        });
        node_fs_1.default.rmdirSync(dirPath);
    }
};
exports.rmDirSync = rmDirSync;
const downloadWithProgressBar = (url, dest) => __awaiter(void 0, void 0, void 0, function* () {
    const progressBar = new cli_progress_1.default.Bar({
        format: ' [{bar}] {percentage}% | ETA: {eta}s'
    }, cli_progress_1.default.Presets.shades_classic);
    const downloader = new node_downloader_helper_1.DownloaderHelper(url, dest, { override: { skip: true } });
    downloader.on('start', () => progressBar.start(100, 0));
    downloader.on('progress', (stats) => {
        progressBar.update(stats.progress);
    });
    downloader.on('skip', (skipInfo) => {
        progressBar.stop();
        logger_1.default.info(`Download skipped! File already present at: '${skipInfo.filePath}'\n`);
    });
    downloader.on('end', (downloadInfo) => {
        progressBar.stop();
        logger_1.default.info(`${ansi_colors_1.default.green('Success!')} File downloaded at: '${downloadInfo.filePath}'\n`);
    });
    downloader.on('error', () => progressBar.stop());
    return yield downloader.start();
});
exports.downloadWithProgressBar = downloadWithProgressBar;
